@@ -35,6 +35,8 @@ struct _MagnifierPrivate {
 	GtkWidget *w;
 	GtkWidget *canvas;
 	GdkWindow *root;
+	GdkWindow *overlay;
+	GdkPixmap *source_drawable;
 	GdkDrawable *cursor;
         int cursor_default_size_x;
         int cursor_default_size_y;
