@@ -239,11 +239,9 @@ can_open_display (gchar *display_name)
     Display *d;
     if ((d = XOpenDisplay (display_name)))
     {
-	    printf ("yes\n");
 	XCloseDisplay (d);
 	return TRUE;
     }
-    printf ("no\n");
     return FALSE;
 }
 
@@ -1157,10 +1155,8 @@ magnifier_set_property (BonoboPropertyBag *bag,
 	switch (arg_id) {
 	case MAGNIFIER_SOURCE_DISPLAY_PROP:
 		full_display_string = BONOBO_ARG_GET_STRING (arg);
-		printf ("%s\n", full_display_string);
 		if (can_open_display (full_display_string))
 		{
-			printf ("here\n");
 		    GSList *zoom_region_params = NULL;
 		    magnifier->source_screen_num =
 			magnifier_parse_display_name (magnifier,
@@ -1858,7 +1854,13 @@ magnifier_new (gboolean override_redirect)
 	ret = bonobo_activation_active_server_register (
 		MAGNIFIER_OAFIID, BONOBO_OBJREF (mag));
 	if (ret != Bonobo_ACTIVATION_REG_SUCCESS)
-	    g_error ("Error registering magnifier server.\n");
+	    if ( ret == Bonobo_ACTIVATION_REG_ALREADY_ACTIVE)
+	    {
+		printf("An instance of magnifier is already active. Exiting Program.\n");
+		exit(0);
+	    }
+	    else
+		g_error ("Error registering magnifier server.\n");
 
 	g_idle_add (magnifier_reset_struts_at_idle, mag);
 	g_idle_add (magnifier_reset_overlay_at_idle, mag);
